==> ghc-mod-5.8.0.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/ghc-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.8.0.0
id: ghc-mod-5.8.0.0-ISVhGcIyGh0HjDH5o7lMR0
key: ghc-mod-5.8.0.0-ISVhGcIyGh0HjDH5o7lMR0
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: https://github.com/DanielG/ghc-mod
synopsis: Happy Haskell Hacking
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    GhcMod GhcModExe.Boot GhcModExe.Browse GhcModExe.CaseSplit
    GhcModExe.Check GhcModExe.Debug GhcModExe.FillSig GhcModExe.Find
    GhcModExe.Flag GhcModExe.Info GhcModExe.Internal GhcModExe.Lang
    GhcModExe.Lint GhcModExe.Modules GhcModExe.PkgDoc GhcModExe.Test
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.DebugLogger Language.Haskell.GhcMod.Doc
    Language.Haskell.GhcMod.DynFlags Language.Haskell.GhcMod.DynFlagsTH
    Language.Haskell.GhcMod.Error Language.Haskell.GhcMod.FileMapping
    Language.Haskell.GhcMod.Gap Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.LightGhc Language.Haskell.GhcMod.Logger
    Language.Haskell.GhcMod.Logging Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types
    Language.Haskell.GhcMod.Options.DocUtils
    Language.Haskell.GhcMod.Options.Help
    Language.Haskell.GhcMod.Options.Options
    Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.Pretty Language.Haskell.GhcMod.Read
    Language.Haskell.GhcMod.SrcUtils Language.Haskell.GhcMod.Stack
    Language.Haskell.GhcMod.Target Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
abi: 684a284e1883a8e38c6987e840f30509
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ghc-mod-5.8.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/ghc-mod-5.8.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.8.0.0-ISVhGcIyGh0HjDH5o7lMR0
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1
    cabal-helper-0.7.3.0-HJagp3EyBd8BoEWTDNRt5s containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    djinn-ghc-0.0.2.3-GEjRaNuJkRM46zEKf9JKya
    extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1
    fclabels-2.0.3.2-4EezQlp7n1w9uoh5Y3yxAt filepath-1.4.1.1 ghc-8.0.2
    ghc-boot-8.0.2 ghc-paths-0.1.0.9-AhaDlGOsRAepox069XzG
    ghc-syb-utils-0.2.3.2-AfldvmVhqxk2tP2cUto6vv
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    hlint-2.0.9-7zNfOpx5K9ADHkECLmuMlV
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-journal-0.7.2-l98JVATk3sBU40Y2KQiIC
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    old-time-1.1.0.3-EZzkBJ4NQxX4hHavrKxgaT
    optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
    pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH process-1.4.3.0
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    template-haskell-2.11.1.0 temporary-1.2.1-JeTWp1TBc5gLAbmEVNVXbt
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ghc-mod-5.8.0.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/ghc-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.8.0.0
id: ghc-mod-5.8.0.0-Gj7C3l0LMcK3nwD4BcZJus
key: ghc-mod-5.8.0.0-Gj7C3l0LMcK3nwD4BcZJus
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: https://github.com/DanielG/ghc-mod
synopsis: Happy Haskell Hacking
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    GhcMod GhcModExe.Boot GhcModExe.Browse GhcModExe.CaseSplit
    GhcModExe.Check GhcModExe.Debug GhcModExe.FillSig GhcModExe.Find
    GhcModExe.Flag GhcModExe.Info GhcModExe.Internal GhcModExe.Lang
    GhcModExe.Lint GhcModExe.Modules GhcModExe.PkgDoc GhcModExe.Test
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.DebugLogger Language.Haskell.GhcMod.Doc
    Language.Haskell.GhcMod.DynFlags Language.Haskell.GhcMod.DynFlagsTH
    Language.Haskell.GhcMod.Error Language.Haskell.GhcMod.FileMapping
    Language.Haskell.GhcMod.Gap Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.LightGhc Language.Haskell.GhcMod.Logger
    Language.Haskell.GhcMod.Logging Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types
    Language.Haskell.GhcMod.Options.DocUtils
    Language.Haskell.GhcMod.Options.Help
    Language.Haskell.GhcMod.Options.Options
    Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.Pretty Language.Haskell.GhcMod.Read
    Language.Haskell.GhcMod.SrcUtils Language.Haskell.GhcMod.Stack
    Language.Haskell.GhcMod.Target Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
abi: 686244dfd06eee17ce92e4f0a13758d2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ghc-mod-5.8.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/ghc-mod-5.8.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.8.0.0-Gj7C3l0LMcK3nwD4BcZJus
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1
    cabal-helper-0.7.3.0-HJagp3EyBd8BoEWTDNRt5s containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    djinn-ghc-0.0.2.3-GEjRaNuJkRM46zEKf9JKya
    extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1
    fclabels-2.0.3.2-4EezQlp7n1w9uoh5Y3yxAt filepath-1.4.1.1 ghc-8.0.2
    ghc-boot-8.0.2 ghc-paths-0.1.0.9-AhaDlGOsRAepox069XzG
    ghc-syb-utils-0.2.3.2-AfldvmVhqxk2tP2cUto6vv
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    hlint-2.0.9-7zNfOpx5K9ADHkECLmuMlV
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-journal-0.7.2-LTHwyh11CHYF8EWMUf1T2Q
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    old-time-1.1.0.3-EZzkBJ4NQxX4hHavrKxgaT
    optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
    pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH process-1.4.3.0
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    template-haskell-2.11.1.0 temporary-1.2.1.1-6DswsWwyVfs4EvmtlA0bHh
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
